"use strict";

var _map2 = _interopRequireDefault(require("lodash/map"));

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _reactTestRenderer = _interopRequireDefault(require("react-test-renderer"));

require("jest-styled-components");

var _theme = require("../../utils/theme");

var _ = _interopRequireDefault(require("."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getFirstRowName = function getFirstRowName(table) {
  return table.find('tbody tr').first().find('td').first().text();
};

describe('DataTable', function () {
  var data = [{
    name: 'Bob',
    email: 'a@weave.works'
  }, {
    name: 'Albert',
    // Notice the emails are inverted to test sorting by this field
    email: 'b@weave.works'
  }, {
    name: 'Ty',
    email: 'c@weave.works'
  }];
  describe('snapshots', function () {
    it('renders rows', function () {
      var tree = _reactTestRenderer.default.create((0, _theme.withTheme)(_react.default.createElement(_.default, {
        data: data,
        columns: [{
          value: 'name',
          label: 'Name'
        }, {
          value: 'email',
          label: 'Email'
        }]
      }, function (rows) {
        return (0, _map2.default)(rows, function (r) {
          return _react.default.createElement("tr", {
            key: r.email
          }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
        });
      }))).toJSON();

      expect(tree).toMatchSnapshot();
    });
    it('sorts rows by a field', function () {
      var tree = _reactTestRenderer.default.create((0, _theme.withTheme)(_react.default.createElement(_.default, {
        data: data,
        sortBy: "email",
        columns: [{
          value: 'name',
          label: 'Name'
        }, {
          value: 'email',
          label: 'Email'
        }]
      }, function (rows) {
        return (0, _map2.default)(rows, function (r) {
          return _react.default.createElement("tr", {
            key: r.email
          }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
        });
      }))).toJSON();

      expect(tree).toMatchSnapshot();
    });
    it('sorts fields by a give order', function () {
      var tree = _reactTestRenderer.default.create((0, _theme.withTheme)(_react.default.createElement(_.default, {
        data: data,
        sortBy: "email",
        sortOrder: "desc",
        columns: [{
          value: 'name',
          label: 'Name'
        }, {
          value: 'email',
          label: 'Email'
        }]
      }, function (rows) {
        return (0, _map2.default)(rows, function (r) {
          return _react.default.createElement("tr", {
            key: r.email
          }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
        });
      }))).toJSON();

      expect(tree).toMatchSnapshot();
    });
    it('renders nested rows', function () {
      var nesteData = [{
        workloadId: 'default:deployment/myworkload',
        containers: [{
          name: 'nginx',
          behind: '4'
        }, {
          name: 'redis',
          behind: '1'
        }, {
          name: 'envoy',
          behind: '2'
        }]
      }, {
        workloadId: 'default:deployment/helloworld',
        containers: [{
          name: 'helloworld',
          behind: '2'
        }]
      }];

      var tree = _reactTestRenderer.default.create((0, _theme.withTheme)(_react.default.createElement(_.default, {
        data: nesteData,
        sortBy: "workloadId",
        sortOrder: "asc",
        columns: [{
          value: 'workloadId',
          label: 'Workload'
        }, {
          value: 'containers',
          label: 'Containers'
        }, {
          value: 'behind',
          label: 'Behind'
        }]
      }, function (rows) {
        return (0, _map2.default)(rows, function (r) {
          return _react.default.createElement("tbody", {
            key: r.workloadId
          }, (0, _map2.default)(r.containers, function (c, i) {
            return _react.default.createElement("tr", {
              key: c.name
            }, i === 0 && _react.default.createElement("td", {
              rowSpan: r.containers.length
            }, r.workloadId), _react.default.createElement("td", null, c.name), _react.default.createElement("td", null, c.behind));
          }));
        });
      }))).toJSON();

      expect(tree).toMatchSnapshot();
    });
    it('renders extra headers', function () {
      var tree = _reactTestRenderer.default.create((0, _theme.withTheme)(_react.default.createElement(_.default, {
        data: data,
        columns: [{
          value: 'name',
          label: 'Name'
        }, {
          value: 'email',
          label: 'Email'
        }],
        extraHeaders: [_react.default.createElement("div", null, "Some other header"), _react.default.createElement("div", null, "Another one")]
      }, function (rows) {
        return (0, _map2.default)(rows, function (r) {
          return _react.default.createElement("tr", {
            key: r.email
          }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
        });
      }))).toJSON();

      expect(tree).toMatchSnapshot();
    });
    it('renders an element instead of a label', function () {
      var tree = _reactTestRenderer.default.create((0, _theme.withTheme)(_react.default.createElement(_.default, {
        data: data,
        columns: [{
          value: 'name',
          element: _react.default.createElement("i", {
            className: "fa fa-some-icon"
          })
        }, {
          value: 'email',
          label: 'Email'
        }]
      }, function (rows) {
        return (0, _map2.default)(rows, function (r) {
          return _react.default.createElement("tr", {
            key: r.email
          }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
        });
      }))).toJSON();

      expect(tree).toMatchSnapshot();
    });
    it('renders column widths', function () {
      var tree = _reactTestRenderer.default.create((0, _theme.withTheme)(_react.default.createElement(_.default, {
        data: data,
        columns: [{
          value: 'name',
          label: 'Name',
          width: '20px'
        }, {
          value: 'email',
          label: 'Email',
          width: '80px'
        }]
      }, function (rows) {
        return (0, _map2.default)(rows, function (r) {
          return _react.default.createElement("tr", {
            key: r.email
          }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
        });
      }))).toJSON();

      expect(tree).toMatchSnapshot();
    });
  });
  it('sorts on click', function () {
    var table = (0, _enzyme.mount)((0, _theme.withTheme)(_react.default.createElement(_.default, {
      data: data,
      sortBy: "email",
      sortOrder: "asc",
      columns: [{
        value: 'name',
        label: 'Name'
      }, {
        value: 'email',
        label: 'Email'
      }]
    }, function (rows) {
      return (0, _map2.default)(rows, function (r) {
        return _react.default.createElement("tr", {
          key: r.email
        }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
      });
    })));
    var $nameHeader = table.find('thead td').at(0);
    var $emailHeader = table.find('thead td').at(1);
    $nameHeader.simulate('click'); // Albert should be first, since we are sorting by name now.

    expect(getFirstRowName(table)).toEqual('Albert'); // Back to email

    $emailHeader.simulate('click');
    expect(getFirstRowName(table)).toEqual('Bob'); // Click again to reverse the order.

    $emailHeader.simulate('click');
    expect(getFirstRowName(table)).toEqual('Ty'); // Back to ascending

    $emailHeader.simulate('click');
    expect(getFirstRowName(table)).toEqual('Bob');
  });
  it('handles custom sorting logic', function () {
    // Custom sort function to sort by length instead of alphabetized.
    var sortByNameLength = function sortByNameLength(row) {
      return row.name.length;
    };

    var table = (0, _enzyme.mount)((0, _theme.withTheme)(_react.default.createElement(_.default, {
      data: data,
      sortBy: "name",
      sortOrder: "asc",
      columns: [{
        value: 'name',
        label: 'Name'
      }, {
        value: 'email',
        label: 'Email'
      }],
      sortOverrides: {
        name: sortByNameLength
      }
    }, function (rows) {
      return (0, _map2.default)(rows, function (r) {
        return _react.default.createElement("tr", {
          key: r.email
        }, _react.default.createElement("td", null, r.name), _react.default.createElement("td", null, r.email));
      });
    }))); // Ty has the shortest name, so they should be first

    expect(getFirstRowName(table)).toEqual('Ty');
  });
});